@@ -1,9 +1,8 @@
 #![no_main]
 #![no_std]
 
-// basic tag exemple to be used with basic anchor exemple
-// Values are not very stable on these exemple, could be a good idea to improve
-// the configuration module (try to use )
+// simple tag exemple to be used with simple anchor exemple to implement RTT communication
+
 use panic_rtt_target as _;
 use rtt_target::{rprintln, rtt_init_print};
 use cortex_m_rt::entry;
@@ -14,7 +13,10 @@ use stm32f1xx_hal::{
 	spi::{Mode, Phase, Polarity, Spi},
 };
 use embedded_hal::digital::v2::OutputPin;
-use dw3000::{hl, Config};
+use dw3000::{
+	hl,
+	Config,
+};
 use nb::block;
 
 #[entry]
@@ -100,20 +102,21 @@ fn main() -> ! {
 	rprintln!("l'état devrait etre en IDLE = {:#x?}", dw3000.state());
 
 	/*
-		dw3000
-			.ll()
-			.aon_dig_cfg()
-			.write(|w| w.onw_pgfcal(1))
-			.expect("Write to onw_pgfcal failed.");
-	*/
+	dw3000
+		.ll()
+		.aon_dig_cfg()
+		.write(|w| w.onw_pgfcal(1))
+		.expect("Write to onw_pgfcal failed.");
+*/
 	// delay.delay_ms(1000u16);
 
 	// on cré un buffer pour stoquer le resultat message du receveur
 	let mut buffer = [0; 1024];
 	// let mut received_instant: Instant;
-	dw3000.set_antenna_delay(0, 0).unwrap();
+	dw3000.set_antenna_delay(0,0).unwrap();
 
 	loop {
+
 		/**************************** */
 		/********* RECEIVER ********* */
 		/**************************** */
@@ -122,16 +125,13 @@ fn main() -> ! {
 			.expect("Failed configure receiver.");
 
 		// on recupère un message avec une fonction bloquante
-		let t2 = block!(receiving.r_wait(&mut buffer))
-			.expect("bug pas stp")
-			.rx_time
-			.value();
+		let t2 = block!(receiving.r_wait(&mut buffer)).expect("bug pas stp").rx_time.value();
 		let t2_tab = [
-			((t2 >> (8 * 4)) & 0xFF) as u8,
-			((t2 >> (8 * 3)) & 0xFF) as u8,
-			((t2 >> (8 * 2)) & 0xFF) as u8,
-			((t2 >> 8) & 0xFF) as u8,
-			(t2 & 0xFF) as u8,
+			((t2 >> (8 * 4) ) & 0xFF ) as u8,
+			((t2 >> (8 * 3) ) & 0xFF ) as u8,
+			((t2 >> (8 * 2) ) & 0xFF ) as u8,
+			((t2 >>  8      ) & 0xFF ) as u8,
+			 (t2              & 0xFF ) as u8,
 		];
 
 		dw3000 = receiving
@@ -145,19 +145,18 @@ fn main() -> ! {
 		let mut sending = dw3000
 			.send(
 				&t2_tab,
-				hl::SendTime::Now, /* Delayed(received_instant + FIXED_DELAY -
-				                    * Instant::new(low_bits as u64).unwrap()), */
+				hl::SendTime::Now, //Delayed(received_instant + FIXED_DELAY - Instant::new(low_bits as u64).unwrap()),
 				Config::default(),
 			)
 			.expect("Failed configure transmitter");
-
+			
 		let t3 = block!(sending.s_wait()).unwrap().value();
 		let t3_tab = [
-			((t3 >> (8 * 4)) & 0xFF) as u8,
-			((t3 >> (8 * 3)) & 0xFF) as u8,
-			((t3 >> (8 * 2)) & 0xFF) as u8,
-			((t3 >> 8) & 0xFF) as u8,
-			(t3 & 0xFF) as u8,
+			((t3 >> (8 * 4) ) & 0xFF ) as u8,
+			((t3 >> (8 * 3) ) & 0xFF ) as u8,
+			((t3 >> (8 * 2) ) & 0xFF ) as u8,
+			((t3 >>  8      ) & 0xFF ) as u8,
+			 (t3              & 0xFF ) as u8,
 		];
 
 		dw3000 = sending.finish_sending().expect("Failed to finish sending");
@@ -171,12 +170,11 @@ fn main() -> ! {
 		let mut sending = dw3000
 			.send(
 				&t3_tab,
-				hl::SendTime::Now, /* Delayed(received_instant + FIXED_DELAY -
-				                    * Instant::new(low_bits as u64).unwrap()), */
+				hl::SendTime::Now, //Delayed(received_instant + FIXED_DELAY - Instant::new(low_bits as u64).unwrap()),
 				Config::default(),
 			)
 			.expect("Failed configure transmitter");
-
+			
 		let _t5 = block!(sending.s_wait()).unwrap();
 
 		dw3000 = sending.finish_sending().expect("Failed to finish sending");
