@@ -1,7 +1,7 @@
 #![no_main]
 #![no_std]
 
-// Exemple to look at the different module states
+// Exemple to look at the different module states 
 
 use panic_rtt_target as _;
 use rtt_target::{rprintln, rtt_init_print};
@@ -32,7 +32,10 @@ where
 	if dw3000.idle_pll_passed()? {
 		rprintln!("IDLE_PLL state (cpclock = 1)");
 	}
-	rprintln!("the state is {:#x?}\n\n", dw3000.state()?);
+	rprintln!(
+		"the state is {:#x?}\n\n",
+		dw3000.state()?
+	);
 	Ok(())
 }
 
